Index: exampleparties/anac2019/agentgg/pom.xml
===================================================================
--- exampleparties/anac2019/agentgg/pom.xml	(revision 21)
+++ exampleparties/anac2019/agentgg/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties.anac2019</groupId>
 	<artifactId>agentgg</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.6</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/anac2019/winkyagent/pom.xml
===================================================================
--- exampleparties/anac2019/winkyagent/pom.xml	(revision 21)
+++ exampleparties/anac2019/winkyagent/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties.anac2019</groupId>
 	<artifactId>winkyagent</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.6</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/boulware/pom.xml
===================================================================
--- exampleparties/boulware/pom.xml	(revision 21)
+++ exampleparties/boulware/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties</groupId>
 	<artifactId>boulware</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.10</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/comparebids/pom.xml
===================================================================
--- exampleparties/comparebids/pom.xml	(revision 21)
+++ exampleparties/comparebids/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties</groupId>
 	<artifactId>comparebids</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.6</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/conceder/pom.xml
===================================================================
--- exampleparties/conceder/pom.xml	(revision 21)
+++ exampleparties/conceder/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties</groupId>
 	<artifactId>conceder</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.10</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/hardliner/pom.xml
===================================================================
--- exampleparties/hardliner/pom.xml	(revision 21)
+++ exampleparties/hardliner/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties</groupId>
 	<artifactId>hardliner</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.10</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/humangui/pom.xml
===================================================================
--- exampleparties/humangui/pom.xml	(revision 21)
+++ exampleparties/humangui/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties</groupId>
 	<artifactId>humangui</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.6</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/linear/pom.xml
===================================================================
--- exampleparties/linear/pom.xml	(revision 21)
+++ exampleparties/linear/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties</groupId>
 	<artifactId>linear</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.10</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/randomparty/pom.xml
===================================================================
--- exampleparties/randomparty/pom.xml	(revision 21)
+++ exampleparties/randomparty/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties</groupId>
 	<artifactId>randomparty</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.6</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/randompartypy/pom.xml
===================================================================
--- exampleparties/randompartypy/pom.xml	(revision 21)
+++ exampleparties/randompartypy/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties</groupId>
 	<artifactId>randompyparty</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.10</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/simpleboa/pom.xml
===================================================================
--- exampleparties/simpleboa/pom.xml	(revision 21)
+++ exampleparties/simpleboa/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties</groupId>
 	<artifactId>simpleboaparty</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.6</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/simpleshaop/pom.xml
===================================================================
--- exampleparties/simpleshaop/pom.xml	(revision 21)
+++ exampleparties/simpleshaop/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties</groupId>
 	<artifactId>simpleshaop</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.6</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 
Index: exampleparties/timedependentparty/pom.xml
===================================================================
--- exampleparties/timedependentparty/pom.xml	(revision 21)
+++ exampleparties/timedependentparty/pom.xml	(revision 22)
@@ -6,5 +6,5 @@
 	<groupId>geniusweb.exampleparties</groupId>
 	<artifactId>timedependentparty</artifactId>
-	<version>1.5.0</version> <!-- must equal ${geniusweb.version} -->
+	<version>1.5.1</version> <!-- must equal ${geniusweb.version} -->
 	<packaging>jar</packaging>
 
@@ -17,5 +17,5 @@
 		<passwd>${env.ARTIFACTORY_PASS}</passwd>
 		<jackson-2-version>2.9.10</jackson-2-version>
-		<geniusweb.version>1.5.0</geniusweb.version>
+		<geniusweb.version>1.5.1</geniusweb.version>
 	</properties>
 

Index: exampleparties/randomparty/src/main/java/geniusweb/exampleparties/randomparty/RandomParty.java
===================================================================
--- exampleparties/randomparty/src/main/java/geniusweb/exampleparties/randomparty/RandomParty.java	(revision 21)
+++ exampleparties/randomparty/src/main/java/geniusweb/exampleparties/randomparty/RandomParty.java	(revision 22)
@@ -39,7 +39,17 @@
  * A simple party that places random bids and accepts when it receives an offer
  * with sufficient utility.
  * <h2>voting</h2> If the party receives a parameter "minPower", it will
  * {@link Vote} using that minPower instead of the default value 2 if it
  * receives a {@link Voting} request.
  */
 public class RandomParty extends DefaultParty {
@@ -109,5 +119,6 @@
 	@Override
 	public String getDescription() {
-		return "places random bids until it can accept an offer with utility >0.6";
+		return "places random bids until it can accept an offer with utility >0.6. "
+				+ "Parameters minPower and maxPower can be used to control voting behaviour.";
 	}
 
@@ -164,12 +175,13 @@
 	 */
 	private Votes vote(Voting voting) throws IOException {
-		Object val = settings.getParameters().get("minPowwer");
-		Integer n = (val instanceof Integer) ? (Integer) val : 2;
-		for (Bid bid : voting.getBids()) {
-			System.out.println("Bid " + bid + "="
-					+ ((UtilitySpace) profileint.getProfile()).getUtility(bid));
-		}
+		Object val = settings.getParameters().get("minPower");
+		Integer minpower = (val instanceof Integer) ? (Integer) val : 2;
+		val = settings.getParameters().get("maxPower");
+		Integer maxpower = (val instanceof Integer) ? (Integer) val
+				: Integer.MAX_VALUE;
+
 		List<Vote> votes = voting.getBids().stream().distinct()
-				.filter(bid -> isGood(bid)).map(bid -> new Vote(me, bid, n))
+				.filter(bid -> isGood(bid))
+				.map(bid -> new Vote(me, bid, minpower, maxpower))
 				.collect(Collectors.toList());
 		return new Votes(me, votes);
@@ -39,7 +39,17 @@
  * A simple party that places random bids and accepts when it receives an offer
  * with sufficient utility.
- * <h2>voting</h2> If the party receives a parameter "minPower", it will
- * {@link Vote} using that minPower instead of the default value 2 if it
- * receives a {@link Voting} request.
+ * <h2>parameters</h2>
+ * <table>
+ * <tr>
+ * <td>minPower</td>
+ * <td>This value is used as minPower for placed {@link Vote}s. Default value is
+ * 2.</td>
+ * </tr>
+ * <tr>
+ * <td>maxPower</td>
+ * <td>This value is used as maxPower for placed {@link Vote}s. Default value is
+ * infinity.</td>
+ * </tr>
+ * </table>
  */
 public class RandomParty extends DefaultParty {